:orphan:

Setting BarContainer orientation
--------------------------------
`.BarContainer` now accepts a new string argument ``orientation``.
It can be either ``vertical`` or ``horizontal``, default is ``None``.

